@@ -1,5 +1,5 @@
 from lazysignup.middleware import ALLOW_LAZY_REGISTRY
 
-def allow_lazy(func):
+def allow_lazy_user(func):
     ALLOW_LAZY_REGISTRY[func] = True
     return func
\ No newline at end of file
